@@ -1,7 +1,4 @@
-use {
-    crate::*,
-    std::fmt,
-};
+use {crate::*, std::fmt};
 
 pub type AtomId = usize;
 
@@ -15,11 +12,7 @@ enum TokenType {
 }
 
 /// Something that can be added to the tree
-pub enum Token<Op, Atom>
-where
-    Op: fmt::Debug + Clone + PartialEq,
-    Atom: fmt::Debug + Clone,
-{
+pub enum Token<Op, Atom> {
     Atom(Atom),
     Operator(Op),
     OpeningParenthesis,
@@ -39,10 +32,9 @@ where
     tail: NodeId, // node index - where to add new nodes
     last_pushed: TokenType,
     op_count: usize, // number of operators
-    openess: usize, // opening pars minus closing pars
+    openness: usize, // opening pars minus closing pars
 }
 
-
 impl<Op, Atom> Default for BeTree<Op, Atom>
 where
     Op: fmt::Debug + Clone + PartialEq,
@@ -56,7 +48,7 @@ where
             tail: 0,
             last_pushed: TokenType::Nothing,
             op_count: 0,
-            openess: 0,
+            openness: 0,
         }
     }
 }
@@ -70,11 +62,10 @@ where
         self.atoms == other.atoms
             && self.nodes == other.nodes
             && self.head == other.head
-            && self.head == other.head
             && self.tail == other.tail
             && self.last_pushed == other.last_pushed
             && self.op_count == other.op_count
-            && self.openess == other.openess
+            && self.openness == other.openness
     }
 }
 
@@ -83,7 +74,6 @@ where
     Op: fmt::Debug + Clone + PartialEq,
     Atom: fmt::Debug + Clone,
 {
-
     /// create an empty expression, ready to be completed
     pub fn new() -> Self {
         Self::default()
@@ -127,14 +117,14 @@ where
     }
 
     /// iterate on all atoms
-    pub fn iter_atoms<'a>(&'a self) -> std::slice::Iter<'a, Atom> {
+    pub fn iter_atoms(&self) -> std::slice::Iter<'_, Atom> {
         self.atoms.iter()
     }
 
     /// returns a reference to the last atom if it's the last
     /// pushed token. Return none in other cases (including
     /// when no atom has been pushed at all)
-    pub fn current_atom<'a>(&'a self) -> Option<&'a Atom> {
+    pub fn current_atom(&self) -> Option<&Atom> {
         if self.last_pushed == TokenType::Atom {
             self.atoms.last()
         } else {
@@ -145,8 +135,8 @@ where
     /// return the count of open parenthesis minus the
     /// one of closing parenthesis. Illegal closing parenthesis
     /// are ignored (hence why this count can be a usize)
-    pub fn get_openess(&self) -> usize {
-        self.openess
+    pub fn get_openness(&self) -> usize {
+        self.openness
     }
 
     fn store_node(&mut self, node: Node<Op>) -> usize {
@@ -154,17 +144,17 @@ where
         self.nodes.len() - 1
     }
 
-    fn store_atom(&mut self,  atom: Atom) -> usize {
+    fn store_atom(&mut self, atom: Atom) -> usize {
         self.atoms.push(atom);
         self.atoms.len() - 1
     }
 
     fn add_child(&mut self, child: Child) {
         debug_assert!(!self.nodes[self.tail].is_full());
-        if !self.nodes[self.tail].left.is_some() {
-            self.nodes[self.tail].left = child;
-        } else {
+        if self.nodes[self.tail].left.is_some() {
             self.nodes[self.tail].right = child;
+        } else {
+            self.nodes[self.tail].left = child;
         }
     }
 
@@ -188,10 +178,10 @@ where
     pub fn push_atom(&mut self, atom: Atom) {
         self.last_pushed = TokenType::Atom;
         let atom_idx = self.store_atom(atom);
-        if !self.nodes[self.tail].left.is_some() {
-            self.nodes[self.tail].left = Child::Atom(atom_idx);
-        } else {
+        if self.nodes[self.tail].left.is_some() {
             self.nodes[self.tail].right = Child::Atom(atom_idx);
+        } else {
+            self.nodes[self.tail].left = Child::Atom(atom_idx);
         }
     }
 
@@ -208,13 +198,12 @@ where
         self.atoms.last_mut().unwrap()
     }
 
-
     /// add an opening parenthesis to the expression
     pub fn open_par(&mut self) {
         self.last_pushed = TokenType::OpeningPar;
         let node_idx = self.store_node(Node::empty());
         self.add_child_node(node_idx);
-        self.openess += 1;
+        self.openness += 1;
     }
 
     /// add a closing parenthesis to the expression
@@ -222,7 +211,7 @@ where
         self.last_pushed = TokenType::ClosingPar;
         if let Some(parent) = self.nodes[self.tail].parent {
             self.tail = parent;
-            self.openess -= 1;
+            self.openness -= 1;
         }
         // we might want to return an error if there are too
         // many closing parenthesis in the future
@@ -241,38 +230,38 @@ where
     }
 
     fn push_binary_operator(&mut self, operator: Op) {
-        if self.nodes[self.tail].is_full() {
-            // we replace the current tail
-            // which becomes the left child of the new node
-            let new_idx = self.store_node(Node {
-                operator: Some(operator),
-                parent: self.nodes[self.tail].parent,
-                left: Child::Node(self.tail),
-                right: Child::None,
-                unary: false,
-            });
-            // we connect the parent to the new node
-            if let Some(parent_idx) = self.nodes[new_idx].parent {
-                if self.nodes[parent_idx].left == Child::Node(self.tail) {
-                    // the connection was to the left child
-                    self.nodes[parent_idx].left = Child::Node(new_idx);
-                } else {
-                    // it must have been to the right child
-                    debug_assert_eq!(self.nodes[parent_idx].right, Child::Node(self.tail));
-                    self.nodes[parent_idx].right = Child::Node(new_idx);
-                }
-            } else {
-                // the replaced node was the head
-                self.head = new_idx;
-            }
-            // we connect the tail to the new node
-            //if let Child::Node(child_idx) = self.nodes[self.tail]I
-            self.nodes[self.tail].parent = Some(new_idx);
-            // and we update the tail
-            self.tail = new_idx;
-        } else {
+        if !self.nodes[self.tail].is_full() {
             self.nodes[self.tail].operator = Some(operator);
+            return;
         }
+        // we replace the current tail
+        // which becomes the left child of the new node
+        let new_idx = self.store_node(Node {
+            operator: Some(operator),
+            parent: self.nodes[self.tail].parent,
+            left: Child::Node(self.tail),
+            right: Child::None,
+            unary: false,
+        });
+        // we connect the parent to the new node
+        let Some(parent_idx) = self.nodes[new_idx].parent else {
+            // the replaced node was the head
+            self.head = new_idx;
+            return;
+        };
+        if self.nodes[parent_idx].left == Child::Node(self.tail) {
+            // the connection was to the left child
+            self.nodes[parent_idx].left = Child::Node(new_idx);
+        } else {
+            // it must have been to the right child
+            debug_assert_eq!(self.nodes[parent_idx].right, Child::Node(self.tail));
+            self.nodes[parent_idx].right = Child::Node(new_idx);
+        }
+        // we connect the tail to the new node
+        //if let Child::Node(child_idx) = self.nodes[self.tail]I
+        self.nodes[self.tail].parent = Some(new_idx);
+        // and we update the tail
+        self.tail = new_idx;
     }
 
     /// add an operator right of the expression
@@ -298,10 +287,7 @@ where
     /// sense just after an atom)
     pub fn accept_unary_operator(&self) -> bool {
         use TokenType::*;
-        match self.last_pushed {
-            Nothing | Operator | OpeningPar => true,
-            _ => false,
-        }
+        matches!(self.last_pushed, Nothing | Operator | OpeningPar)
     }
 
     /// tell whether it would make sense to push a binary
@@ -309,10 +295,7 @@ where
     /// sense just after another operator)
     pub fn accept_binary_operator(&self) -> bool {
         use TokenType::*;
-        match self.last_pushed {
-            Atom | ClosingPar => true,
-            _ => false,
-        }
+        matches!(self.last_pushed, Atom | ClosingPar)
     }
 
     /// tell whether it would make sense to push an atom
@@ -320,10 +303,7 @@ where
     /// sense just after a closing parenthesis)
     pub fn accept_atom(&self) -> bool {
         use TokenType::*;
-        match self.last_pushed {
-            Nothing | Operator | OpeningPar => true,
-            _ => false,
-        }
+        matches!(self.last_pushed, Nothing | Operator | OpeningPar)
     }
 
     /// tell whether it would make sense to open a parenthesis
@@ -331,10 +311,7 @@ where
     /// a closing parenthesis)
     pub fn accept_opening_par(&self) -> bool {
         use TokenType::*;
-        match self.last_pushed {
-            Nothing | Operator | OpeningPar => true,
-            _ => false,
-        }
+        matches!(self.last_pushed, Nothing | Operator | OpeningPar)
     }
 
     /// tell whether it would make sense to close a parenthesis
@@ -343,10 +320,7 @@ where
     /// opening ones)
     pub fn accept_closing_par(&self) -> bool {
         use TokenType::*;
-        match self.last_pushed {
-            Atom | ClosingPar if self.openess > 0 => true,
-            _ => false,
-        }
+        matches!(self.last_pushed, Atom | ClosingPar if self.openness > 0)
     }
 
     /// produce a new expression by applying a transformation on all atoms
@@ -369,7 +343,7 @@ where
             tail: self.tail,
             last_pushed: self.last_pushed,
             op_count: self.op_count,
-            openess: self.openess,
+            openness: self.openness,
         })
     }
 
@@ -406,7 +380,9 @@ where
     {
         Ok(match child {
             Child::None => None,
-            Child::Node(node_idx) => self.eval_node_faillible(eval_atom, eval_op, short_circuit, node_idx)?,
+            Child::Node(node_idx) => {
+                self.eval_node_faillible(eval_atom, eval_op, short_circuit, node_idx)?
+            }
             Child::Atom(atom_idx) => Some(eval_atom(&self.atoms[atom_idx])?),
         })
     }
@@ -425,21 +401,18 @@ where
     {
         let node = &self.nodes[node_idx];
         let left_value = self.eval_child(eval_atom, eval_op, short_circuit, node.left);
-        if let Some(op) = &node.operator {
-            if let Some(left_value) = left_value {
-                if short_circuit(op, &left_value) {
-                    Some(left_value)
-                } else {
-                    let right_value = self.eval_child(eval_atom, eval_op, short_circuit, node.right);
-                    Some(eval_op(op, left_value, right_value))
-                }
-            } else {
-                // probably pathological
-                None
-            }
-        } else {
-            left_value
+        let Some(op) = &node.operator else {
+            return left_value;
+        };
+        let Some(left_value) = left_value else {
+            // probably pathological
+            return None;
+        };
+        if short_circuit(op, &left_value) {
+            return Some(left_value);
         }
+        let right_value = self.eval_child(eval_atom, eval_op, short_circuit, node.right);
+        Some(eval_op(op, left_value, right_value))
     }
 
     fn eval_node_faillible<Err, R, EvalAtom, EvalOp, ShortCircuit>(
@@ -456,28 +429,19 @@ where
     {
         let node = &self.nodes[node_idx];
         let left_value = self.eval_child_faillible(eval_atom, eval_op, short_circuit, node.left)?;
-        Ok(
-            if let Some(op) = &node.operator {
-                if let Some(left_value) = left_value {
-                    if short_circuit(op, &left_value) {
-                        Some(left_value)
-                    } else {
-                        let right_value = self.eval_child_faillible(
-                            eval_atom,
-                            eval_op,
-                            short_circuit,
-                            node.right,
-                        )?;
-                        Some(eval_op(op, left_value, right_value)?)
-                    }
-                } else {
-                    // probably pathological
-                    None
-                }
-            } else {
-                left_value
-            }
-        )
+        let Some(op) = &node.operator else {
+            return Ok(left_value);
+        };
+        let Some(left_value) = left_value else {
+            // probably pathological
+            return Ok(None);
+        };
+        if short_circuit(op, &left_value) {
+            return Ok(Some(left_value));
+        };
+        let right_value =
+            self.eval_child_faillible(eval_atom, eval_op, short_circuit, node.right)?;
+        Ok(Some(eval_op(op, left_value, right_value)?))
     }
 
     /// evaluate the expression.
@@ -542,7 +506,8 @@ where
             parent: None,
             right: Child::None,
             unary: false,
-        } = self.nodes[self.head] {
+        } = self.nodes[self.head]
+        {
             self.nodes[node_id].parent = None;
             self.head = node_id;
         }
@@ -562,13 +527,11 @@ where
     pub fn print_node(&self, node_id: NodeId, indent: usize) {
         let node = &self.nodes[node_id];
         println!("[{}] {:?}", node_id, &node.operator);
-        self.print_child(node.left, indent+1);
-        self.print_child(node.right, indent+1);
+        self.print_child(node.left, indent + 1);
+        self.print_child(node.right, indent + 1);
     }
 
     pub fn print_tree(&self) {
         self.print_node(self.head, 0);
     }
 }
-
-
